==> sinfo_0.0.42.orig.tar.gz: sinfo-0.0.42/sinfod/sinfo.idlx.parser.cc <==
/*******************************************************************************
** File gererated from sinfo.idlx
**
** Created: Wed Jun 15 08:21:25 2011
**      by: idlxcompiler version 0.0.1
**
** WARNING!
** All changes made in this file will be lost when recompiling idlx file.
*******************************************************************************/

#include <boost/bind.hpp>
#include "messagebasictypes.h"
#include "messagesinfotypes.h"
#include "messagecomplextypes.h"
#include "messagecontainertypes.h"
#include "templateparser.h"
#include "sinfo.idlx.parser.h"
using namespace std;
using namespace Msg;


enum
{
  GetSinfoListRequest=1,
  GetSinfoListReply=2,
  GetFilteredSinfoListRequest=3,
  GetFilteredSinfoListReply=4
};

SinfoParser::SinfoParser(boost::shared_ptr<SinfoWorker> sinfoWorkerPtr)
{
  TemplateParser_1ret_0< std::list < Wsinfo > > * getSinfoListParserPtr = new TemplateParser_1ret_0< std::list < Wsinfo > >;
  getSinfoListParserPtr->callWorkerSignal.connect(boost::bind(&SinfoWorker::getSinfoList, sinfoWorkerPtr, _1));
  addParser(GetSinfoListRequest, GetSinfoListReply, Parser::SPtr(getSinfoListParserPtr));

  TemplateParser_1ret_1< std::list < Wsinfo >, std::string > * getFilteredSinfoListParserPtr = new TemplateParser_1ret_1< std::list < Wsinfo >, std::string >;
  getFilteredSinfoListParserPtr->callWorkerSignal.connect(boost::bind(&SinfoWorker::getFilteredSinfoList, sinfoWorkerPtr, _1, _2));
  addParser(GetFilteredSinfoListRequest, GetFilteredSinfoListReply, Parser::SPtr(getFilteredSinfoListParserPtr));

};

==> sinfo_0.0.46.orig.tar.gz: sinfo-0.0.46/sinfod/sinfo.idlx.parser.cc <==
/*******************************************************************************
** File gererated from sinfo.idlx
**
** Created: Mon May 14 19:47:41 2012
**      by: idlxcompiler version 0.0.1
**
** WARNING!
** All changes made in this file will be lost when recompiling idlx file.
*******************************************************************************/

#include <boost/bind.hpp>
#include "messagebasictypes.h"
#include "messagesinfotypes.h"
#include "messagecomplextypes.h"
#include "messagestlcontainertypes.h"
using namespace Msg;
#include "templateparser.h"
#include "sinfo.idlx.parser.h"
using namespace std;


enum
{
  GetSinfoListRequest=1,
  GetSinfoListReply=2,
  GetFilteredSinfoListRequest=3,
  GetFilteredSinfoListReply=4
};

SinfoParser::SinfoParser(boost::shared_ptr<SinfoWorker> sinfoWorkerPtr)
{
  TemplateParser_1ret_0< std::list < Wsinfo > > * getSinfoListParserPtr = new TemplateParser_1ret_0< std::list < Wsinfo > >;
  getSinfoListParserPtr->callWorkerSignal.connect(boost::bind(&SinfoWorker::getSinfoList, sinfoWorkerPtr, _1));
  addParser(GetSinfoListRequest, GetSinfoListReply, Parser::SPtr(getSinfoListParserPtr));

  TemplateParser_1ret_1< std::list < Wsinfo >, std::string > * getFilteredSinfoListParserPtr = new TemplateParser_1ret_1< std::list < Wsinfo >, std::string >;
  getFilteredSinfoListParserPtr->callWorkerSignal.connect(boost::bind(&SinfoWorker::getFilteredSinfoList, sinfoWorkerPtr, _1, _2));
  addParser(GetFilteredSinfoListRequest, GetFilteredSinfoListReply, Parser::SPtr(getFilteredSinfoListParserPtr));

};
